@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Net::SAML2::Binding::POST;
-our $VERSION = '0.80'; # VERSION
+our $VERSION = '0.81'; # VERSION
 
 use Moose;
 use Carp qw(croak);
@@ -19,8 +19,8 @@ with 'Net::SAML2::Role::VerifyXML';
 
 
 has 'cacert' => (isa => 'Maybe[Str]', is => 'ro');
-
 has 'cert' => (isa => 'Str', is => 'ro', required => 0, predicate => 'has_cert');
+has 'cert_text' => (isa => 'Str', is => 'ro');
 has 'key'  => (isa => 'Str', is => 'ro', required => 0, predicate => 'has_key');
 
 
@@ -33,6 +33,9 @@ sub handle_response {
     $self->verify_xml(
         $xml,
         no_xml_declaration => 1,
+        $self->cert_text ? (
+            cert_text => $self->cert_text
+        ) : (),
         $self->cacert ? (
             cacert => $self->cacert
         ) : (),
@@ -96,7 +99,7 @@ Net::SAML2::Binding::POST - HTTP POST binding for SAML
 
 =head1 VERSION
 
-version 0.80
+version 0.81
 
 =head1 SYNOPSIS
 
@@ -121,6 +124,34 @@ Arguments:
 
 path to the CA certificate for verification
 
+=item B<cert>
+
+path to a certificate that is added to the signed XML.  It needs to be the
+certificate that includes the public key related to the B<key>
+
+=item B<cert_text>
+
+text form of the certificate in FORMAT_ASN1 or FORMAT_PEM that is used to
+verify the signed XML.
+
+=item B<key>
+
+path to a key used to sign the XML.
+
+=item B<cert>
+
+path to a certificate that is added to the signed XML.  It needs to be the
+certificate that includes the public key related to the B<key>
+
+=item B<cert_text>
+
+text form of the certificate in FORMAT_ASN1 or FORMAT_PEM that is used to
+verify the signed XML.
+
+=item B<key>
+
+path to a key used to sign the XML.
+
 =back
 
 =head2 handle_response( $response )
